import{i as k}from"./metadata.0aaab781.js";import{W as h}from"./Watermark.e4dc5fa7.js";import{F as b}from"./PhArrowSquareOut.vue.a3cf64eb.js";import{d as w,eo as v,f as x,e as C,u as e,o as a,X as m,b as p,w as r,R as D,c as n,aF as f,d5 as y,aR as I,eb as z,dd as _,ec as F,e9 as T,ed as B,$ as H}from"./vue-router.e3ef87f0.js";import{u as L}from"./workspaceStore.ba59e8f0.js";import"./index.ad645270.js";import{L as N}from"./LoadingOutlined.e83670fa.js";import{C as R}from"./Card.9e74c9cd.js";import"./PhBug.vue.5783ebba.js";import"./PhCheckCircle.vue.e0058912.js";import"./PhKanban.vue.97825602.js";import"./PhWebhooksLogo.vue.259f6aaf.js";import"./url.d7fc9f74.js";import"./colorHelpers.68e96910.js";import"./TabPane.16834058.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="5982110d-bb3a-4df9-9149-d200469a0ca8",o._sentryDebugIdIdentifier="sentry-dbid-5982110d-bb3a-4df9-9149-d200469a0ca8")}catch{}})();const S={key:0,class:"home-container"},V=w({__name:"Home",setup(o){const i=v(),l=L(),u=x(()=>{var s;return((s=l.state.workspace)==null?void 0:s.sidebar.filter(c=>c.id!=="home"))||[]}),d=C(null),g=async(s,c)=>{d.value=c,await i.push({path:`/${s}`}),d.value=null};return(s,c)=>e(l).state.workspace?(a(),m("div",S,[p(e(_),{vertical:"",gap:"large",class:"cards-container"},{default:r(()=>[u.value.length===0?(a(),n(e(y),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:r(()=>[f(" There are no forms available for you. ")]),_:1})):(a(!0),m(I,{key:1},z(u.value,t=>(a(),n(e(R),{key:t.id,class:B(["form-card",{loading:d.value===t.id}]),"body-style":{cursor:"pointer"},onClick:W=>g(t.path,t.id)},{default:r(()=>[p(e(_),{gap:"large",align:"center",justify:"space-between"},{default:r(()=>[(a(),n(F(e(k)(t.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),p(e(y),{style:{"font-size":"18px","font-weight":"500"}},{default:r(()=>[f(T(t.name),1)]),_:2},1024),d.value!==t.id?(a(),n(e(b),{key:0,size:"20"})):(a(),n(e(N),{key:1,style:{"font-size":"20px"}}))]),_:2},1024)]),_:2},1032,["class","onClick"]))),128))]),_:1}),p(h,{class:"watermark","page-id":"home",locale:e(l).state.workspace.language},null,8,["locale"])])):D("",!0)}});const Z=H(V,[["__scopeId","data-v-060376d1"]]);export{Z as default};
//# sourceMappingURL=Home.1cd4ece9.js.map
