import{S as s,dA as d,dB as i}from"./vue-router.e3ef87f0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[c]="e8863e98-c6c7-4182-aeb7-5fe7408f30dd",e._sentryDebugIdIdentifier="sentry-dbid-e8863e98-c6c7-4182-aeb7-5fe7408f30dd")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:f,TimePicker:m,QuarterPicker:o,RangePicker:a}=d(i),y=s(n,{WeekPicker:t,MonthPicker:r,YearPicker:f,RangePicker:a,TimePicker:m,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(a.name,a),e.component(r.name,r),e.component(t.name,t),e.component(o.name,o),e)});export{y as D,r as M,o as Q,a as R,t as W};
//# sourceMappingURL=dayjs.ad2491a8.js.map
