import{C as t,E as i,K as d,a as c,M as b,c as f,P as l,R as y,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.e0066c61.js";import"./vue-router.e3ef87f0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="747a3928-292b-4631-b09e-c620cf892cb6",e._sentryDebugIdIdentifier="sentry-dbid-747a3928-292b-4631-b09e-c620cf892cb6")}catch{}})();export{t as CancellationTokenSource,i as Emitter,d as KeyCode,c as KeyMod,b as MarkerSeverity,f as MarkerTag,l as Position,y as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.867cfa74.js.map
