import{_ as f}from"./AbstraLogo.vue_vue_type_script_setup_true_lang.d1e74e3b.js";import{B as y}from"./BaseLayout.3b732e48.js";import{d as p,D as m,K as v,$ as u,aZ as g,a_ as b,o as _,X as h,a as r,Y as s,ea as w,eo as S,W as k,c as L,w as n,b as i,u as $}from"./vue-router.e3ef87f0.js";import{u as x}from"./editor.a99f287e.js";import{b as B}from"./index.74f6e7f5.js";import"./Logo.19ebe967.js";import"./workspaceStore.ba59e8f0.js";import"./url.d7fc9f74.js";import"./colorHelpers.68e96910.js";import"./asyncComputed.e840076d.js";import"./index.6f617d93.js";import"./Avatar.715e2ca3.js";import"./index.45410f8d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="97a56099-73f1-48c7-9f40-d0e1c2a4fa9d",e._sentryDebugIdIdentifier="sentry-dbid-97a56099-73f1-48c7-9f40-d0e1c2a4fa9d")}catch{}})();const I=p({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"#ea576a"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const o=m({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...v(o)}}});const D={class:"v-spinner"};function P(e,o,a,d,c,l){return g((_(),h("div",D,[r("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4),r("div",{class:"v-beat v-beat-even",style:s(e.spinnerStyle)},null,4),r("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4)],512)),[[b,e.loading]])}const K=u(I,[["render",P],["__scopeId","data-v-06538001"]]),R={class:"content"},j=p({__name:"ProjectLogin",setup(e){const o=w(),a=S(),d=x();function c(){const t=new URL(location.href);t.searchParams.delete("api-key"),a.replace(t.pathname+t.search)}function l(){const t=o.query["api-key"];if(typeof t=="string")return t}return k(async()=>{const t=l();if(!t){a.push({name:"error"});return}await d.createLogin(t).then(c),a.push({name:"workspace"})}),(t,z)=>(_(),L(y,null,{navbar:n(()=>[i($(B),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{title:n(()=>[i(f)]),_:1})]),content:n(()=>[r("div",R,[i(K)])]),_:1}))}});const Z=u(j,[["__scopeId","data-v-944edebb"]]);export{Z as default};
//# sourceMappingURL=ProjectLogin.5b987720.js.map
