import{a as g}from"./asyncComputed.e840076d.js";import{d as y,ea as _,W as w,u as e,o as l,c as b,X as x,b as a,w as o,d9 as C,aF as p,dd as h,bP as I,a as k,e9 as v}from"./vue-router.e3ef87f0.js";import"./gateway.e3730daa.js";import{O as B}from"./organization.365449ea.js";import"./tables.8b5b16f2.js";import{C as c}from"./router.7553e78c.js";import{L as D}from"./LoadingContainer.e164c4c5.js";import{A as N}from"./index.cd9b2c78.js";import{C as z}from"./Card.9e74c9cd.js";import"./popupNotifcation.bf248d47.js";import"./record.9f354c97.js";import"./string.5524ff61.js";import"./TabPane.16834058.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="340015d5-c841-4339-b0d0-3fa046e5575e",t._sentryDebugIdIdentifier="sentry-dbid-340015d5-c841-4339-b0d0-3fa046e5575e")}catch{}})();const M={key:1},A={style:{display:"flex","justify-content":"flex-start","font-size":"24px"}},H=y({__name:"Billing",setup(t){const s=_().params.organizationId,{loading:u,result:f}=g(()=>B.get(s));w(()=>{location.search.includes("upgrade")&&c.showNewMessage("I want to upgrade my plan")});const m=()=>c.showNewMessage("I want to upgrade my plan");return(V,j)=>e(u)?(l(),b(D,{key:0})):(l(),x("div",M,[a(e(h),{justify:"space-between",align:"center"},{default:o(()=>[a(e(C),{level:3},{default:o(()=>[p("Current plan")]),_:1})]),_:1}),a(e(N),{style:{"margin-top":"0"}}),a(e(z),{style:{width:"300px"},title:"Plan"},{extra:o(()=>[a(e(I),{onClick:m},{default:o(()=>[p("Upgrade")]),_:1})]),default:o(()=>{var r,i,d;return[k("div",A,v((d=(i=(r=e(f))==null?void 0:r.billingMetadata)==null?void 0:i.plan)!=null?d:"No active plan"),1)]}),_:1})]))}});export{H as default};
//# sourceMappingURL=Billing.b5a0316d.js.map
