import{$ as d,o,X as n,Z as s,a,R as r}from"./vue-router.e3ef87f0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="0da415c9-f70b-4bd5-88e3-3eb332cc9871",e._sentryDebugIdIdentifier="sentry-dbid-0da415c9-f70b-4bd5-88e3-3eb332cc9871")}catch{}})();const c={},i={class:"base-layout"},f={class:"base-middle"},u={key:0,class:"base-footer"};function _(e,t){return o(),n("div",i,[s(e.$slots,"sidebar",{},void 0,!0),a("section",f,[s(e.$slots,"navbar",{},void 0,!0),s(e.$slots,"content",{},void 0,!0),e.$slots.footer?(o(),n("section",u,[s(e.$slots,"footer",{},void 0,!0)])):r("",!0)])])}const y=d(c,[["render",_],["__scopeId","data-v-9ad5be20"]]);export{y as B};
//# sourceMappingURL=BaseLayout.3b732e48.js.map
