import{d as a,o,X as s,b as d,u as r,bx as _,$ as c}from"./vue-router.e3ef87f0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="9ca6f156-30c4-4fef-a4e4-52830310d033",e._sentryDebugIdIdentifier="sentry-dbid-9ca6f156-30c4-4fef-a4e4-52830310d033")}catch{}})();const i={class:"centered"},f=a({__name:"LoadingContainer",setup(e){return(n,t)=>(o(),s("div",i,[d(r(_))]))}});const u=c(f,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.e164c4c5.js.map
