import{d as r,o as d,c as o,w as a,b as f,Z as u,u as s,dd as i,ey as l,eB as c,bP as p}from"./vue-router.e3ef87f0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="d841d1f9-539b-4123-9146-a5fa4a840e0b",e._sentryDebugIdIdentifier="sentry-dbid-d841d1f9-539b-4123-9146-a5fa4a840e0b")}catch{}})();const y=r({__name:"AbstraButton",setup(e){return(t,n)=>(d(),o(s(p),l(c(t.$attrs)),{default:a(()=>[f(s(i),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:a(()=>[u(t.$slots,"default")]),_:3})]),_:3},16))}});export{y as _};
//# sourceMappingURL=AbstraButton.vue_vue_type_script_setup_true_lang.7d8e6557.js.map
