import"./App.vue_vue_type_style_index_0_lang.b2ec52b5.js";import{_ as a}from"./App.vue_vue_type_style_index_0_lang.b2ec52b5.js";import"./workspaceStore.ba59e8f0.js";import"./vue-router.e3ef87f0.js";import"./url.d7fc9f74.js";import"./colorHelpers.68e96910.js";import"./PlayerConfigProvider.d7d0bb7a.js";import"./index.0d9beae4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},f=new Error().stack;f&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[f]="8c90b6f2-b911-4fc3-b4c4-f5b33d7e8f57",e._sentryDebugIdIdentifier="sentry-dbid-8c90b6f2-b911-4fc3-b4c4-f5b33d7e8f57")}catch{}})();export{a as default};
//# sourceMappingURL=App.1fb42124.js.map
