import{_ as y}from"./AbstraLogo.vue_vue_type_script_setup_true_lang.d1e74e3b.js";import{C as b}from"./ContentLayout.9508ac8e.js";import{l as h}from"./fetch.1531f1e4.js";import{d as w,eo as g,ea as k,e as v,o as r,c,w as n,b as f,a as C,u as d,d5 as p,aF as _,$ as x}from"./vue-router.e3ef87f0.js";import{u as I,E as T}from"./editor.a99f287e.js";import{C as D}from"./Card.9e74c9cd.js";import"./Logo.19ebe967.js";import"./workspaceStore.ba59e8f0.js";import"./url.d7fc9f74.js";import"./colorHelpers.68e96910.js";import"./asyncComputed.e840076d.js";import"./TabPane.16834058.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="9bdcb7b9-f9fc-496f-93e7-d138acd0c6ad",e._sentryDebugIdIdentifier="sentry-dbid-9bdcb7b9-f9fc-496f-93e7-d138acd0c6ad")}catch{}})();const L={class:"card-content"},N=w({__name:"Welcome",setup(e){const o=g(),{query:i}=k(),a=I();a.loadLogin();const l=v(!0),u=async()=>{l.value=!1,setInterval(()=>{var t;return window.location.replace(((t=a==null?void 0:a.links)==null?void 0:t.project)||T.consoleUrl)},5e3)};return(async()=>{const t=i.token,s=await h("/_editor/web-editor/welcome",{method:"POST",body:JSON.stringify({token:t}),headers:{"Content-Type":"application/json"}});if(!s.ok)return u();const{ok:m}=await s.json();if(!m)return u();await o.push({name:"workspace"})})(),(t,s)=>(r(),c(b,null,{default:n(()=>[f(d(D),{bordered:!1,class:"card"},{default:n(()=>[C("div",L,[f(y,{style:{"margin-bottom":"10px"}}),l.value?(r(),c(d(p),{key:0},{default:n(()=>[_("Loading...")]),_:1})):(r(),c(d(p),{key:1},{default:n(()=>[_("Authentication failed. You are been redirected...")]),_:1}))])]),_:1})]),_:1}))}});const q=x(N,[["__scopeId","data-v-a984ec04"]]);export{q as default};
//# sourceMappingURL=Welcome.5935a960.js.map
