:root{--main-font-family: DM Sans, sans-serif}:root{--abstra-main-color-dark: #343b46}.p-dropdown{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel{background-color:#fff;padding:10px}
