.connector-card[data-v-e3719550]{cursor:pointer;transition:all .3s;&[data-v-e3719550]:hover{box-shadow:0 0 15px #0000001a}&.unavailable[data-v-e3719550]{opacity:.7;&[data-v-e3719550]:hover{box-shadow:none}}}.connectors-grid[data-v-40b20da6]{display:grid;grid-template-columns:repeat(auto-fill,minmax(300px,1fr));gap:20px}
