[data-v-22706e2c]:root{--abstra-main-color-dark: #343b46}.loading[data-v-22706e2c]{position:absolute;top:0;left:0;width:100vw;height:100vh;display:flex;justify-content:center;align-items:center}.unset-thread-container[data-v-22706e2c]{justify-content:center;align-items:center;height:100%}.unset-thread-container .message[data-v-22706e2c]{width:420px;text-align:center;font-size:16px;margin-bottom:40px}
