import"./vue-router.e3ef87f0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="16a7f1eb-cca6-4817-a157-1228fab469a8",e._sentryDebugIdIdentifier="sentry-dbid-16a7f1eb-cca6-4817-a157-1228fab469a8")}catch{}})();const i=1e3,d=e=>{let n=null;return{startPolling:()=>{const t=async()=>{var o;try{!document.hidden&&!e.keepPollingOnOutOfFocus&&await e.task()}finally{n=setTimeout(t,(o=e.interval)!=null?o:i)}};t()},endPolling:()=>{n&&clearTimeout(n)}}};export{d as u};
//# sourceMappingURL=polling.9969b38e.js.map
