import{b as r,u as n}from"./workspaceStore.ba59e8f0.js";import{W as c}from"./PlayerConfigProvider.d7d0bb7a.js";import{d as f,g as d,r as i,u as o,o as u,c as p,w as l,R as _,b as m}from"./vue-router.e3ef87f0.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[s]="91f109bd-fd31-42ef-9b5d-f8e28e0cc5df",t._sentryDebugIdIdentifier="sentry-dbid-91f109bd-fd31-42ef-9b5d-f8e28e0cc5df")}catch{}})();const h=f({__name:"App",setup(t){const s=r(),e=n();return e.actions.fetch(),d(()=>s.user,e.actions.fetch),(w,y)=>{const a=i("RouterView");return o(e).state.workspace?(u(),p(c,{key:0,"main-color":o(e).state.workspace.mainColor,background:o(e).state.workspace.theme,"font-family":o(e).state.workspace.fontFamily,locale:o(e).state.workspace.language},{default:l(()=>[m(a,{style:{height:"100vh",width:"100%"}})]),_:1},8,["main-color","background","font-family","locale"])):_("",!0)}}});export{h as _};
//# sourceMappingURL=App.vue_vue_type_style_index_0_lang.b2ec52b5.js.map
