import{P as k}from"./api.240e21a9.js";import{b as _}from"./workspaceStore.ba59e8f0.js";import{d as w,L as g,N as l,e as v,o as a,X as h,b as s,w as T,u as e,c as p,R as m,$ as K}from"./vue-router.e3ef87f0.js";import{K as R,_ as I,W as P,P as S,b as V}from"./WorkflowView.edbfd154.js";import{A as c,T as x}from"./TabPane.16834058.js";import"./Card.9e74c9cd.js";import"./fetch.1531f1e4.js";import"./metadata.0aaab781.js";import"./PhBug.vue.5783ebba.js";import"./PhCheckCircle.vue.e0058912.js";import"./PhKanban.vue.97825602.js";import"./PhWebhooksLogo.vue.259f6aaf.js";import"./url.d7fc9f74.js";import"./colorHelpers.68e96910.js";import"./polling.9969b38e.js";import"./asyncComputed.e840076d.js";import"./PhQuestion.vue.bb633fb3.js";import"./ant-design.ab86670b.js";import"./index.45410f8d.js";import"./index.738a9a5d.js";import"./index.2150a909.js";import"./CollapsePanel.b237cad2.js";import"./index.cd9b2c78.js";import"./index.8b67a975.js";import"./Badge.e09547ac.js";import"./PhArrowCounterClockwise.vue.b57d3f96.js";import"./Workflow.f292df08.js";import"./validations.494fd4a4.js";import"./string.5524ff61.js";import"./uuid.94c3ff7b.js";import"./index.0d9beae4.js";import"./workspaces.3503b70f.js";import"./record.9f354c97.js";import"./index.60f1e584.js";import"./PhArrowDown.vue.a29a48a3.js";import"./LoadingOutlined.e83670fa.js";import"./DeleteOutlined.b3749286.js";import"./PhDownloadSimple.vue.c60d2774.js";import"./utils.2789cdf5.js";import"./LoadingContainer.e164c4c5.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="877964f1-87d6-41fc-896d-a9d18e01c92c",t._sentryDebugIdIdentifier="sentry-dbid-877964f1-87d6-41fc-896d-a9d18e01c92c")}catch{}})();const W={class:"threads-view"},A=w({__name:"Threads",setup(t){const r=_().authHeaders,u=new k(r),i=new S(r),y=new V(r),b=new g(l.array(l.string()),"kanban-selected-stages"),o=v("kanban");return(B,d)=>(a(),h("div",W,[s(e(x),{activeKey:o.value,"onUpdate:activeKey":d[0]||(d[0]=f=>o.value=f)},{default:T(()=>[s(e(c),{key:"kanban",tab:"Kanban View"}),s(e(c),{key:"table",tab:"Table View"}),s(e(c),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),o.value==="kanban"?(a(),p(R,{key:0,"kanban-repository":e(i),"kanban-stages-storage":e(b),"stage-run-repository":e(y)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):m("",!0),o.value==="table"?(a(),p(I,{key:1,"kanban-repository":e(i)},null,8,["kanban-repository"])):m("",!0),o.value==="workflow"?(a(),p(P,{key:2,"kanban-repository":e(i),"workflow-api":e(u)},null,8,["kanban-repository","workflow-api"])):m("",!0)]))}});const ge=K(A,[["__scopeId","data-v-d6c18c3e"]]);export{ge as default};
//# sourceMappingURL=Threads.0ca72afa.js.map
